@@ -2,7 +2,7 @@
 module Main where
 
 import Options.Applicative                              -- http://hackage.haskell.org/package/optparse-applicative
-import Options.Applicative.Help.Pretty  (string)        -- Necessary to format help text -- https://github.com/pcapriotti/optparse-applicative/issues/90#issuecomment-49868254
+import Prettyprinter (pretty)
 import System.Console.ANSI
 import Data.Version (showVersion)
 
@@ -98,7 +98,7 @@ subcommandO =
 
         helpText desc cmd argsFoot examplesFoot = (progDesc desc <>
                 header (cliName_ ++ ": "++ cmd ++" command") <>
-                footerDoc (Just $ string $ unlines ["Argument notes:\n", argsFoot, "Examples:\n", examplesFoot]))
+                footerDoc (Just $ pretty $ unlines ["Argument notes:\n", argsFoot, "Examples:\n", examplesFoot]))
 
 versionOpt = infoOption (showVersion version) (long "version" <> short 'v' <> help "Show package version")
 
@@ -132,7 +132,7 @@ main = do
   where
     optsParser :: ParserInfo Options
     optsParser = info (helper <*> versionOpt <*> commandO)
-                      (fullDesc <> progDesc topDesc <> header cliName_ <> footerDoc (Just $ string topFoot))
+                      (fullDesc <> progDesc topDesc <> header cliName_ <> footerDoc (Just $ pretty topFoot))
 
     -- Like 'configEnigma' but without stack trace and with check for 4 words in a single string
     configEnigmaFromString :: String -> EnigmaConfig
